"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.diffAssocs = exports.addedAssocs = void 0;
const changesetFactory_1 = require("../changesetFactory");
function addedAssocs(model, before, after) {
    return Object.entries(after).reduce((acc, [key, value]) => {
        var _a, _b;
        const beforeValue = before[key];
        const hasBefore = beforeValue !== undefined;
        const assoc = (_a = model.relations) === null || _a === void 0 ? void 0 : _a[key];
        if (hasBefore || !assoc) {
            return acc;
        }
        const idKey = `${model.object}Id`;
        const parentId = (_b = before[idKey]) !== null && _b !== void 0 ? _b : after[idKey];
        return Array.isArray(value)
            ? {
                ...acc,
                [key]: value.map((child) => (0, changesetFactory_1.insert)(assoc.target[0], { ...child, [idKey]: parentId })),
            }
            : {
                ...acc,
                // @ts-expect-error
                [key]: (0, changesetFactory_1.insert)(assoc.target, { ...value, [idKey]: parentId }),
            };
    }, {});
}
exports.addedAssocs = addedAssocs;
function modifiedAssocs(model, before, after) {
    return Object.entries(after).reduce((acc, [key, value]) => {
        var _a, _b;
        const beforeValue = before[key];
        const hasBefore = beforeValue !== undefined;
        const assoc = (_a = model.relations) === null || _a === void 0 ? void 0 : _a[key];
        if (!hasBefore || !assoc) {
            return acc;
        }
        const idKey = `${model.object}Id`;
        const parentId = (_b = before[idKey]) !== null && _b !== void 0 ? _b : after[idKey];
        return Array.isArray(value)
            ? {
                ...acc,
                [key]: value.map((child) => (0, changesetFactory_1.insert)(assoc.target[0], { ...child, [idKey]: parentId })),
            }
            : {
                ...acc,
                // @ts-expect-error
                [key]: (0, changesetFactory_1.insert)(assoc.target, { ...value, [idKey]: parentId }),
            };
    }, {});
}
function diffAssocs(model, before, after) {
    return {
        ...addedAssocs(model, before, after),
        ...modifiedAssocs(model, before, after),
    };
}
exports.diffAssocs = diffAssocs;
//# sourceMappingURL=diffAssocs.js.map